///////////////////////////////////////////////////////////////////////////////
//
// TRIPjxp Programming Examples
//
// Copyright (C) 2006-2009 Tieto Sweden AB - All Rights Reserved
//
///////////////////////////////////////////////////////////////////////////////
//
// Modification History:
//		GF	Aug 11, 2006	Created
//		TF	Sep 26, 2013	Demo use of 'noBaf' property
//
///////////////////////////////////////////////////////////////////////////////
package com.tietoenator.trip.jxp.examples.control;

import com.tietoenator.trip.jxp.TdbControlObject;
import com.tietoenator.trip.jxp.TdbExtendedDatabaseType;
import com.tietoenator.trip.jxp.control.TdbControlObjectList;
import com.tietoenator.trip.jxp.control.TdbDatabaseList;
import com.tietoenator.trip.jxp.examples.util.Console;
import com.tietoenator.trip.jxp.examples.util.SessionFactory;
import com.tietoenator.trip.jxp.grid.TdbGridClusterList;
import com.tietoenator.trip.jxp.session.TdbInterfaceType;
import com.tietoenator.trip.jxp.session.TdbSession;

/**
 * Simplest possible use of a CONTROL list, simply retrieve the list of available
 * databases and show the result.
 */
public class DatabaseList
{

   /**
    * Based on session type, print a list of available databases or grid clusters
    * @param args Not used
    */
   public static void main(String[] args)
   {
      TdbControlObjectList list;
      TdbSession session;
      Console stdin = new Console();

      try
      {
         // Retrieve the appropriate type of list iterator depending on session type
         session = SessionFactory.newInstance("**** Database List Generator ****", true);

         if (session.getSessionType() == TdbInterfaceType.GRID)
         {
            list = new TdbGridClusterList(session);
         }
         else
         {
            boolean nobaf = stdin.readbool("Disable use of BAF files?",false,true);
            list = new TdbDatabaseList(session, TdbExtendedDatabaseType.Any, nobaf);
         }

         // Print out the contents of the list
         ListPrinter.showHeader(false);
         for (TdbControlObject obj : list)
         {
            ListPrinter.showItem(obj,false);
         }

         // Terminate the session
         if (session.getSessionType() != TdbInterfaceType.GRID)
         {
            session.logout();
         }
      }
      catch (Exception e)
      {
         e.printStackTrace();
      }
   }
}
